// ---------------------------------------------------
// Dmo avec la carte YUN (Portes ouvertes)
// Matriel : Carte Yun + shield Tinkerkit  
// + Relais shield v1.3
// + Module DHT11 (Temprature et humidit I2C)
// Projet : Serre
// Version: 2
// Date: 19/7/2015
// Fichier : Yunpopem2.ino
// Commentaires : Mesure de lhumidit et de la luminosit,
// commande du chauffage (Ampoule sur relais).
// ---------------------------------------------------
// Bibliothques
#include <Bridge.h>
#include <YunServer.h>
#include <YunClient.h>
#include <DHT.h>

// Capteur DHT11 
#define DHTPIN A0 
#define DHTTYPE DHT11

// DHT instance
DHT dht(DHTPIN, DHTTYPE);

// Define relay pins
#define RELAY_PIN  7 // Comande Relais 1 de Relais shield v1.3

// Create Yun server
YunServer server;
//----------------------------------------------------
// ---------------------------------------------------
void setup(void)
{
	// Initialize DHT sensor
	dht.begin();

	// Start bridge
	Bridge.begin();

	// Initialize relay pin
	pinMode(RELAY_PIN, OUTPUT);

	// Start server
	server.listenOnLocalhost();
	server.begin();
}
//----------------------------------------------------
// ---------------------------------------------------
void loop(void)
{
	// Get clients coming from server
	YunClient client = server.accept();

	// There is a new client?
	if (client) {
		// Process request
		process(client);

		// Close connection and free resources.
		client.stop();
	}

	// Poll every 50ms
	delay(50);
}
// ---------------------------------------------------
// Process incoming command
void process(YunClient client) {
	// read the command
	String command = client.readStringUntil('/');

	// is "digital" command?
	if (command == "digital") {
		digitalCommand(client);
	}

	// is "analog" command?
	if (command == "DHT") {
		DHTCommand(client);
	}
}
// ---------------------------------------------------
void digitalCommand(YunClient client) {
	int pin, value;

	// Read pin number
	pin = client.parseInt();

	// If the next character is a '/' it means we have an URL
	// with a value like: "/digital/13/1"
	if (client.read() == '/') {
		value = client.parseInt();
		digitalWrite(pin, value);
	}
	else {
		value = digitalRead(pin);
	}

	// Send feedback to client
	client.print(F("Pin D"));
	client.print(pin);
	client.print(F(" set to "));
	client.println(value);
}
// ---------------------------------------------------
void DHTCommand(YunClient client) {
	// Read command and react accordingly
	String command = client.readStringUntil('\r');

	// Return temp measurement
	if (command == "temp"){
		client.print(dht.readTemperature());
	}

	if (command == "hum"){
		client.print(dht.readHumidity());
	}
}
// ----------------------------------------------------
